@@ -2,5 +2,5 @@ from django.contrib import admin
 
 from .models import GenericGroup
 
-admin.site.register(GenericGroup)
+# admin.site.register(GenericGroup)
 
