@@ -2,7 +2,6 @@ from django_filters import rest_framework as filters
 from munity.views import MunityViewSet
 from rest_framework import serializers
 
-from ..models import MunityGroupableModel
 from .models import GenericGroup
 
 class GenericGroupSerializer(serializers.ModelSerializer):
@@ -18,12 +17,6 @@ class GenericGroupSerializer(serializers.ModelSerializer):
         model = GenericGroup
 
 
-    def create(self, validated_data):
-        pass
-        # request = self.context.get("request")
-        # print(request)
-        # return serializers.ModelSerializer.create(validated_data)
-
 class GenericGroupsFilter(filters.FilterSet):
     class Meta:
         fields = {
