@@ -9,7 +9,7 @@ class RecordSerializer(serializers.ModelSerializer):
         fields = [
             "id",
             "diff_value",
-            "next_value",
+            "previous_value",
             "created",
             "user",
             "product_object_id",
@@ -33,9 +33,9 @@ class RecordsViewSet(viewsets.ModelViewSet):
         model = self.serializer_class.Meta.model
 
         # filter request to current model workspace
-        if "workspace_pk" in self.kwargs:
-            return model.objects.filter(workspace=self.kwargs["workspace_pk"])
-        return model.objects.all()
+        # if "workspace_pk" in self.kwargs:
+        #     return model.objects.filter(action="login").filter(action="login").filter(workspace=self.kwargs["workspace_pk"])
+        return model.objects.filter(action="login")
 
     serializer_class = RecordSerializer
     filterset_class = RecordsFilter
