@@ -10,9 +10,11 @@ from ..models import MunityModel
 
 class User(AbstractUser, MunityModel):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4, editable=False)
+    phone_number = models.CharField(max_length=20, blank=True, null=True, default=None)
     avatar = models.ForeignKey("files.File", related_name="avatars", on_delete=models.CASCADE, blank=True, null=True, default=None)
     # user are related to workspace by role., dont use munitymodel workspaces
     workspace = None
+    disabled = models.BooleanField(default=False)
     has_overmind_access = models.BooleanField(default=False, blank=True)
 
     class Meta:
