@@ -1,4 +1,5 @@
 from django_filters import rest_framework as filters
+from ..files.views import FileSerializer
 from rest_framework import serializers, viewsets
 from ..users.models import UserRoleWorkspace
 from rest_framework.exceptions import PermissionDenied
@@ -15,9 +16,16 @@ class WorkspaceSerializer(serializers.ModelSerializer):
             "db_connection",
             "created",
             "modified",
+            "icon",
         ]
         model = Workspace
 
+    # We show full visual on get, on update we only use doc id
+    def to_representation(self, instance):
+        response = super().to_representation(instance)
+        response['icon'] = FileSerializer(instance.icon).data if instance.icon else None
+        return response
+
 
 class WorkspacesFilter(filters.FilterSet):
     class Meta:
